Author:

- Jens-Kristian Krogager


Comments, corrections & suggestions:

- Jonatan Selsing
- Kasper E. Heintz
- Johan P. U. Fynbo
- Sergei Balashev
- Lise Christensen
- Luca Izzo
- Christina Thöne
- Antonio de Ugarte Postigo
- Bo Milvang-Jensen

